force_take

Function force_take 

pub fn force_take() -> Result<MutexGuard<'static, Manager>, Error>
Try to take an instance of the connection manager, ignoring a poisoned cache.

There may only be one Manager instance at the same time. If there already is an instance, a ConcurrentAccessError is returned. If you want a blocking version, use take_blocking.

If a thread has previously panicked while accessing the manager instance, the cache is poisoned. The default implementation, take, returns a [PoisonError][] on subsequent calls. This implementation ignores the poisoned cache and returns the manager instance.

Errors