pub struct Version {
pub git: String,
pub major: u32,
pub minor: u32,
}Expand description
A version of the libnitrokey library.
Use the get_library_version function to query the library
version.
Fields
git: StringThe Git library version as a string.
The library version is the output of git describe --always at compile time, for example
v3.3 or v3.4.1. If the library has not been built from a release, the version string
contains the number of commits since the last release and the hash of the current commit, for
example v3.3-19-gaee920b. If the library has not been built from a Git checkout, this
string may be empty.
major: u32The major library version.
minor: u32The minor library version.