pub fn take_blocking() -> Result<MutexGuard<'static, Manager>, Error>Expand description
Take an instance of the connection manager, blocking until an instance is available.
There may only be one Manager instance at the same time. If there already is an
instance, this method blocks. If you want a non-blocking version, use take.
Errors
PoisonErrorif the lock is poisoned